import React, { Component } from 'react';
import { Link } from 'react-router-dom';
import styled from 'styled-components';

import { GradientBorder } from './styles';

import { PostsList } from './posts';
import { CategoriesList, TagsList } from './categories';
import { PagesList } from './pages';


const Wrapper = styled.div`
  display: flex;
  flex-flow: row wrap;
  max-width: 1400px;
  margin: auto;
`;

const MainCol = styled.main`
  flex: 1 1 0;
  min-width: 600px;
`;

const SideCol = styled.aside`
  flex: 0 1 auto;
  margin: 0 auto;
`;

const Section = styled.section`
  padding: 1rem;
  margin: 3rem 2rem;
  ${GradientBorder(10)}
  border-width: 2px 0;
`;

const SectionTitle = styled.h2`
  font-size: 2rem;
  margin: 0;

  a {
    color: inherit;

    :hover, :active, :focus {
      text-decoration: none;
      color: #666;
    }
  }
`;

const SectionLink = styled(({ main, ...rest}) => <Link {...rest} />)`
  font-size: 1.2rem;

  ${props => props.main && `
    margin: -1.5rem 1rem 2.5rem;
    display: block;
  `}
`;


export default class Home extends Component {

  render() {
    return (
      <Wrapper>
        <MainCol>
          <PostsList amount={3} noPaging />
          <SectionLink main to="/posts">More posts...</SectionLink>
        </MainCol>

        <SideCol>
          <Section>
            <SectionTitle>
              <Link to='/pages'>
                Pages
              </Link>
            </SectionTitle>

            <PagesList amount={3} titles />
            <SectionLink to="/pages">More pages...</SectionLink>
          </Section>

          <Section>
            <SectionTitle>
              <Link to='/categories'>
                Categories
              </Link>
            </SectionTitle>

            <CategoriesList amount={3} titles />
            <SectionLink to="/categories">All categories...</SectionLink>
          </Section>

          <Section>
            <SectionTitle>
              <Link to='/tags'>
                Tags
              </Link>
            </SectionTitle>

            <TagsList amount={3} titles />
            <SectionLink to="/tags">All tags...</SectionLink>
          </Section>
        </SideCol>
      </Wrapper>
    );
  }
}
