import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import Moment from 'moment';

import { TextPlaceholder } from '../styles';


const Text = styled.span`
  list-style: none;
  padding: 0;
`;

const DateFormat = 'Do MMMM YYYY';
const TimeFormat = 'HH:mm';


export default class LinkList extends PureComponent {
  
  static propTypes = {
    date: PropTypes.string,
    modified: PropTypes.string,
  };

  render() {
    const { date:dateStr, modified:modifiedStr } = this.props;

    if (!dateStr) {
      return (
        <Text>
          <TextPlaceholder />
        </Text>
      );
    }

    const date = Moment(dateStr);
    if (!modifiedStr || modifiedStr === dateStr) {
      return (
        <Text>
          {date.format(DateFormat)} at {date.format(TimeFormat)}
        </Text>
      );
    }

    const modified = Moment(modifiedStr);
    if (modified.isSame(date, 'day')) {
      return (
        <Text>
          {date.format(DateFormat)} at {date.format(TimeFormat)}&thinsp;
          (modified at {modified.format(TimeFormat)})
        </Text>
      );
    } else {
      return (
        <Text>
          {date.format(DateFormat)}&thinsp;
          (modified {modified.format(DateFormat)} at {modified.format(TimeFormat)})
        </Text>
      );
    }
  }
}
