import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { Link } from 'react-router-dom';
import styled from 'styled-components';

import { TextPlaceholder } from '../styles';


const List = styled.ul`
  list-style: none;
  padding: 0;
`;

const ListItem = styled.li`
  color: darkblue;
`;


export default class LinkList extends PureComponent {
  
  static propTypes = {
    //OPT: move shape to propTypes.js?
    links: PropTypes.arrayOf(
      PropTypes.shape({
        key: PropTypes.oneOfType([
          PropTypes.string,
          PropTypes.number,
        ]),
        url: PropTypes.oneOfType([
          PropTypes.string,
          PropTypes.shape({
            pathname: PropTypes.string,
            state: PropTypes.string,
          }),
        ]),
        text: PropTypes.string,
      })
    ),
    noneText: PropTypes.string,
  };

  static defaultProps = {
    noneText: "There are no items.",
  }

  render() {
    const { links, noneText } = this.props;

    if (!links) {
      return (
        <List>
          <ListItem>
            <TextPlaceholder />
          </ListItem>
          <ListItem>
            <TextPlaceholder />
          </ListItem>
          <ListItem>
            <TextPlaceholder />
          </ListItem>
        </List>
      );
    }

    if (links.length === 0) {
      return (
        <List>
          <ListItem>
            {noneText}
          </ListItem>
        </List>
      )
    }

    return (
      <List>
        {links.map(l =>
          <ListItem key={l.key}>
            <Link to={l.url}>
              {l.text}
            </Link>
          </ListItem>
        )}
      </List>
    );
  }
}
