import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';

import { Button } from '../styles';


const Wrapper = styled.div``;

const Controls = styled.div`
  display: flex;
  justify-content: center;
`;

const PageButton = styled(Button)`
  padding-left: 0.75em;
  padding-right: 0.75em;
  ${props => props.current && 'color: #39f;'}
`;


export default class LinkList extends PureComponent {
  
  static propTypes = {
    page: PropTypes.number,
    perPage: PropTypes.number,
    items: PropTypes.arrayOf(PropTypes.node),
    total: PropTypes.number,

    changePage: PropTypes.func,
  };

  _renderPageButtons(count) {
    const buttons = [];
    const { page, changePage } = this.props;

    for (let i = 1; i <= count; i++) {
      buttons.push(
        <PageButton key={i} current={i === page} onClick={() => changePage(i)}>
          {i}
        </PageButton>
      );
    }

    return buttons;
  }

  render() {
    const { page, perPage, items, total, changePage } = this.props;
    const pageItems = items.slice(perPage * (page -1), perPage * page);
    const pageCount = Math.ceil(total / perPage);

    return (
      <Wrapper>
        {pageItems}

        {pageCount > 1 && <Controls>
          <Button onClick={() => changePage(page-1)} disabled={page < 2}>
            Previous
          </Button>

          {this._renderPageButtons(pageCount)}

          <Button onClick={() => changePage(page+1)} disabled={page >= pageCount}>
            Next
          </Button>
        </Controls>}
      </Wrapper>
    );
  }
}
