import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';

import { ReactComponent as Comments } from './comments.svg';
import { ReactComponent as Category } from './category.svg';
import { ReactComponent as DateIcon } from './date.svg';
import { ReactComponent as Person } from './person.svg';
import { ReactComponent as Reply } from './reply.svg';


const StyledIcon = styled.i`
  vertical-align: text-top;
  display: inline-block;
  width: 1em;
  height: 1em;
  padding: 0.1em 0.125em 0;
  stroke-width: 0;
  stroke: currentColor;
  fill: currentColor;
`;


export default class Icon extends PureComponent {
  
  static propTypes = {
    name: PropTypes.string,
  };

  getComponent(name) {
    switch (name) {
      case 'comments':
        return Comments;

      case 'category':
        return Category;

      case 'date':
        return DateIcon;

      case 'person':
        return Person;

      case 'reply':
        return Reply;

      default:
        throw `${name} is not a valid icon`; //eslint-disable-line
    }
  }

  render() {
    const { name } = this.props;

    return (
      <StyledIcon as={this.getComponent(name)} />
    );
  }
}
