import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { withRouter } from 'react-router-dom';
import { connect } from 'react-redux';

import { urlify } from '../utils';
import { LinkList } from '../_global';

import { PostsList } from '../posts';

import * as Consts from './constants';
import Category from './Category';


class CategoriesContainer extends Component {

  static propTypes = {
    amount: PropTypes.number,
    titles: PropTypes.bool,
    
    //opt: import {CategoryShape} from './propTypes'; PropTypes.arrayOf(CategoryShape),
    categories: PropTypes.array,
  }

  componentDidMount() {
    this.props.load(this.props.amount);
  }

  componentDidUpdate(prevProps) {
    if (this.props.amount > prevProps.amount) {
      this.props.load(this.props.amount);
    }
  }

  _makeLink(category) {
    return `/categories/${category.id}/${urlify(category.name)}/posts`;
  }

  render() {
    const { categories, amount, titles } = this.props;

    if (titles) {
      return (
        <LinkList links={categories.slice(0, amount).map(c => ({
          key: c.id,
          url: this._makeLink(c),
          text: c.name,
        }))} />
      );
    }

    return categories.slice(0, amount).map(c =>
      c ? <Category key={c.id} category={c} link={this._makeLink(c)}>
        <PostsList category={c.id} titles amount={3} />
      </Category> : null
    );
  }
}


const mapState = (state, ownProps) => {
  return {
    amount: ownProps.amount || 100,
    titles: ownProps.titles,

    categories: Object.values(state.categories.categories),
  };
};

const mapDispatch = (dispatch, ownProps) => ({
  load: (amount) => dispatch({type: Consts.CATEGORIES_REQUEST, amount}),
});

export default withRouter(connect(mapState, mapDispatch)(CategoriesContainer));
