import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { Link } from 'react-router-dom';
import styled from 'styled-components';

import { TextPlaceholder, GradientBorder } from '../styles';
import { Icon } from '../_global';


const Wrapper = styled.article`
  padding: 2rem;
  margin: 1rem 0;
`;

const Header = styled.header`
  padding: 1rem 0 0.5rem 0;
  margin-bottom: 1rem;
  ${GradientBorder()}
  border-width: 2px 0;
`;

const Title = styled.h2`
  font-size: 2rem;
  margin: 0;
  
  a {
    color: inherit;

    :hover, :active, :focus {
      text-decoration: none;
      color: #666;
    }
  }
`;

const HeaderPart = styled.span`
  display: inline-block;
  padding: 0.5rem 1.5rem 0.5rem 0;
  color: #666;
  font-weight: 600;
`;

const Body = styled.main`
  p {
    margin-top: 0;
  }
`;

const Footer = styled.footer`
  ${GradientBorder()}
  border-top-width: 2px;
  padding: 0.5rem 0;
`;


export default class Category extends PureComponent {
  
  static propTypes = {
    //OPT: import {CategoryShape} from './propTypes'; category: CategoryShape,
    category: PropTypes.object,
    link: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.shape({
        pathname: PropTypes.string,
        state: PropTypes.string,
      }),
    ]),
  };

  renderPlaceholder(children) {
    return (
      <Wrapper>
        <Header>
          <Title>
            <TextPlaceholder />
          </Title>

          <HeaderPart>
            <TextPlaceholder />
          </HeaderPart>
        </Header>

        <Body>
          <p>
            <TextPlaceholder />
            <TextPlaceholder />
          </p>
          {children}
        </Body>

        <Footer>
          <TextPlaceholder />
        </Footer>
      </Wrapper>
    );
  }

  renderFull({id, name, description, count}, link, children) {
    return (
      <Wrapper>
        <Header>
          <Title>{name}</Title>

          <HeaderPart>
            <Icon name="comments" />
            {count} article{count !== 1 && 's'}
          </HeaderPart>
        </Header>

        <Body>
          <p>{description}</p>

          {children}
        </Body>

        {link && <Footer>
          <Link to={link}>View category</Link>
        </Footer>}
      </Wrapper>
    );
  }

  render() {
    const {category, link, children} = this.props;

    if (!category) {
      return this.renderPlaceholder(children);
    } else {
      return this.renderFull(category, link, children);
    }
  }
}
