import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { withRouter, Link } from 'react-router-dom';
import { connect } from 'react-redux';

import { urlify } from '../utils';
import { Icon } from '../_global';

import { PostsList } from '../posts';

import * as Consts from './constants';
import Category from './Category';


class CategoryDetail extends Component {

  static propTypes = {
    id: PropTypes.number,
    embed: PropTypes.bool,
    
    //opt: import {CategoryShape} from './propTypes'; CategoryShape,
    category: PropTypes.object,
  }

  componentDidMount() {
    this.props.load(this.props.id);
  }

  componentDidUpdate(prevProps) {
    if (this.props.id !== prevProps.id) {
      this.props.load(this.props.id);
    }
  }

  _makeLink(category) {
    return `/categories/${category.id}/${urlify(category.name)}/posts`;
  }

  render() {
    const { category, embed } = this.props;

    if (!category) {
      return null;
    }

    if (embed) {
      return (
        <Link to={this._makeLink(category)}>
          <Icon name="category" />
          {category.name}
        </Link>
      );
    }

    return (
      <Category key={category.id} category={category}>
        <PostsList category={category.id} amount={2} />
      </Category>
    );
  }
}


const mapState = (state, ownProps) => {
  const id = ownProps.id || Number.parseInt(ownProps.match.params.id);

  return {
    id,
    embed: ownProps.embed,
    category: state.categories.categories[id],
  };
};

const mapDispatch = (dispatch, ownProps) => ({
  load: (id) => dispatch({type: Consts.CATEGORIES_REQUEST, amount: 1, id}),
});

export default withRouter(connect(mapState, mapDispatch)(CategoryDetail));
