import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { Link } from 'react-router-dom';
import styled from 'styled-components';

import { PostsList } from '../posts';

import { TextPlaceholder, GradientBorder } from '../styles';
import { Icon } from '../_global';


const Wrapper = styled.article`
  padding: 2rem;
  margin: 1rem 0;
`;

const Header = styled.header`
  padding: 1rem 0 0.5rem 0;
  margin-bottom: 1rem;
  ${GradientBorder()}
  border-width: 2px 0;
`;

const Title = styled.h2`
  font-size: 1.5rem;
  margin: 0;
  
  a {
    color: inherit;

    :hover, :active, :focus {
      text-decoration: none;
      color: #666;
    }
  }
`;

const Body = styled.main`
  p {
    margin-top: 0;
  }
`;

const Footer = styled.footer`
  ${GradientBorder()}
  border-top-width: 2px;
  padding: 0.5rem 0;
`;


export default class Tag extends PureComponent {
  
  static propTypes = {
    //OPT: import {TagShape} from './propTypes'; tag: TagShape,
    tag: PropTypes.object,
    link: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.shape({
        pathname: PropTypes.string,
        state: PropTypes.string,
      }),
    ]),
  };

  renderPlaceholder() {
    return (
      <Wrapper>
        <Header>
          <Title>
            <TextPlaceholder />
          </Title>
        </Header>

        <Body>
          <p>
            <TextPlaceholder />
            <TextPlaceholder />
          </p>
          <PostsList titles amount={3} />
        </Body>

        <Footer>
          <TextPlaceholder />
        </Footer>
      </Wrapper>
    );
  }

  renderFull({id, name, description, count}, link, children) {
    return (
      <Wrapper>
        <Header>
          <Title>
            {name} (<Icon name="comments" />{count})
          </Title>
        </Header>

        <Body>
          <p>{description}</p>

          {children}
        </Body>

        {link && <Footer>
          <Link to={link}>All posts</Link>
        </Footer>}
      </Wrapper>
    );
  }

  render() {
    const {tag, link, children} = this.props;

    if (!tag) {
      return this.renderPlaceholder();
    } else {
      return this.renderFull(tag, link, children);
    }
  }
}
