import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { withRouter, Link } from 'react-router-dom';
import { connect } from 'react-redux';

import { urlify } from '../utils';

import { PostsList } from '../posts';

import * as Consts from './constants';
import Tag from './Tag';


class TagDetail extends Component {

  static propTypes = {
    id: PropTypes.number,
    embed: PropTypes.bool,
    
    //opt: import {TagShape} from './propTypes'; tag: TagShape,
    tag: PropTypes.object,
  }

  componentDidMount() {
    this.props.load(this.props.id);
  }

  componentDidUpdate(prevProps) {
    if (this.props.id !== prevProps.id) {
      this.props.load(this.props.id);
    }
  }

  _makeLink(tag) {
    return `/tags/${tag.id}/${urlify(tag.name)}/posts`;
  }

  render() {
    const { tag, embed } = this.props;

    if (!tag) {
      return null;
    }

    if (embed) {
      return (
        <Link to={this._makeLink(tag)}>
          #{tag.name}
        </Link>
      );
    }

    return (
      <Tag key={tag.id} tag={tag}>
        <PostsList tag={tag.id} amount={2} />
      </Tag>
    );
  }
}


const mapState = (state, ownProps) => {
  const id = ownProps.id || Number.parseInt(ownProps.match.params.id);

  return {
    id,
    embed: ownProps.embed,
    tag: state.categories.tags[id],
  };
};

const mapDispatch = (dispatch, ownProps) => ({
  load: (id) => dispatch({type: Consts.TAGS_REQUEST, amount: 1, id}),
});

export default withRouter(connect(mapState, mapDispatch)(TagDetail));
