import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { withRouter } from 'react-router-dom';
import { connect } from 'react-redux';

import { urlify } from '../utils';
import { LinkList } from '../_global';

import { PostsList } from '../posts';

import * as Consts from './constants';
import Tag from './Tag';


class TagsContainer extends Component {

  static propTypes = {
    amount: PropTypes.number,
    titles: PropTypes.bool,
    
    //opt: import {CategoryShape} from './propTypes'; PropTypes.arrayOf(CategoryShape),
    categories: PropTypes.array,
  }

  componentDidMount() {
    this.props.load(this.props.amount);
  }

  componentDidUpdate(prevProps) {
    if (this.props.amount > prevProps.amount) {
      this.props.load(this.props.amount);
    }
  }

  _makeLink(category) {
    return `/tags/${category.id}/${urlify(category.name)}/posts`;
  }

  render() {
    const { tags, amount, titles } = this.props;

    if (titles) {
      return (
        <LinkList links={tags.slice(0, amount).map(t => ({
          key: t.id,
          url: this._makeLink(t),
          text: t.name,
        }))} />
      );
    }

    return tags.slice(0, amount).map(t =>
      t ? <Tag key={t.id} tag={t} link={this._makeLink(t)}>
        <PostsList tag={t.id} titles amount={3} />
      </Tag> : null
    );
  }
}


const mapState = (state, ownProps) => {
  return {
    amount: ownProps.amount || 100,
    titles: ownProps.titles,

    tags: Object.values(state.categories.tags),
  };
};

const mapDispatch = (dispatch, ownProps) => ({
  load: (amount) => dispatch({type: Consts.TAGS_REQUEST, amount}),
});

export default withRouter(connect(mapState, mapDispatch)(TagsContainer));
