import { } from 'redux-saga';
import { call, put, select, takeEvery } from 'redux-saga/effects';

import { getCategories, getTags } from './api';
import * as Consts from './constants';


function* loadCategories({amount, id}) {
  try {
    const cached = yield select(state => state.categories.categories);
    const fetch = id ?
      !(id in cached) :
      amount > Object.keys(cached).length;

    if (fetch) {
      const content = yield call(getCategories, amount, id);
      yield put({type: Consts.CATEGORIES_SUCCESS, content});
    }
  } catch (error) {
    console.error(error);
    yield put({type: Consts.CATEGORIES_FAIL, error});
  }
}

function* loadTags({amount, id}) {
  try {
    const cached = yield select(state => state.categories.tags);
    const fetch = id ?
      !(id in cached) :
      amount > Object.keys(cached).length;

    if (fetch) {
      const content = yield call(getTags, amount, id);
      yield put({type: Consts.TAGS_SUCCESS, content});
    }
  } catch (error) {
    console.error(error);
    yield put({type: Consts.TAGS_FAIL, error});
  }
}

export default function* postsFlow() {
  yield takeEvery(Consts.CATEGORIES_REQUEST, loadCategories);
  yield takeEvery(Consts.TAGS_REQUEST, loadTags);
}
