import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';

import { TextPlaceholder, Button } from '../styles';
import { DateTime, Icon } from '../_global';
import UserEmbed from '../users/Embed';
import { urlify } from '../utils';


const Container = styled.article`
  padding: 1rem 0;
  margin: 1rem 0;
`;

const Header = styled.header`
  font-size: 1.2rem;
  line-height: 1.2;

  display: inline-block;
  padding: 0.5rem 0;
  color: #666;
  font-weight: 300;
`;

const Author = styled(UserEmbed)`
  display: inline-block;
  color: #000;
  font-weight: 500;
  margin: 0;
  padding: 0 0.5rem;

  :link:hover, :link:active, :link:focus {
    text-decoration: none;
    color: #69c;
  }
`;

const Body = styled.main`
  p {
    margin: 0;
  }

  ${props => props.faded &&
    `opacity: 0.5;`
  }
`;

const Message = styled.div`
  font-weight: 600;
`;

const Footer = styled.footer`
  padding: 0.5rem 0;
`;


export default class Comment extends PureComponent {
  
  static propTypes = {
    //OPT: import {CommentShape} from './propTypes'; post: CommentShape,
    comment: PropTypes.object,
    writeReply: PropTypes.func,
  };

  renderPlaceholder() {
    return (
      <Container>
        <Header>
          <Author>
            <TextPlaceholder />
          </Author>

          <TextPlaceholder />
        </Header>

        <Body>
          <TextPlaceholder />
          <TextPlaceholder />
        </Body>

        <Footer>
          <TextPlaceholder />
        </Footer>
      </Container>
    );
  }

  renderFull({id, parent, author, author_name, author_url, author_avatar_urls, date, content, status}, writeReply) {
    const held = status === "hold";

    return (
      <Container>
        <Header>
          #{id} by

          <Author user={{
            id: author,
            name: author_name,
            slug: urlify(author_name),
            url: author_url,
            avatar_urls: author_avatar_urls,
          }} />

          <Icon name="date" /><DateTime date={date} />
        </Header>

        <Body dangerouslySetInnerHTML={{__html: content.rendered}} faded={held} />


        <Footer>
          {parent ? `Reply to #${parent}, ` : null}

          {held ?
            <Message>
              Your comment is waiting to be approved
            </Message>
          :
            <Button onClick={() => writeReply(id)}>
              <Icon name="reply" />Reply
            </Button>
          }
        </Footer>
      </Container>
    );
  }

  render() {
    const {comment, writeReply} = this.props;

    if (!comment) {
      return this.renderPlaceholder();
    } else {
      return this.renderFull(comment, writeReply);
    }
  }
}
