import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';

import { Pager } from '../_global';

import Comment from './Comment';
import Form from './Form';


const Container = styled.section`
  margin-top: 3rem;
`;

const Heading = styled.h2`
  margin-bottom: -1rem;
`;


export default class CommentSection extends PureComponent {
  
  static propTypes = {
    comments: PropTypes.array,
    total: PropTypes.number,
    createNew: PropTypes.func,
    pagerProps: PropTypes.object,
  };

  constructor(props) {
    super(props);

    this.state = {
      replyTo: null,
    };

    this.form = React.createRef();
  }

  writeReply(id) {
    this.setState({replyTo: id});
    id && this.form.current.scrollTo();
  }

  render() {
    const { comments, total, createNew, pagerProps } = this.props;
    const { replyTo } = this.state;

    return (
      <Container>
        <Heading>Comments ({total})</Heading>

        <Pager {...pagerProps} items={comments.map(c => c ?
          <Comment key={c.id} comment={c} writeReply={() => this.writeReply(c.id)} />
        : null)} total={total} />

        <Form createNew={createNew} ref={this.form}
          replyTo={replyTo} cancelReply={() => this.writeReply(null)} />
      </Container>
    );
  }
}
