import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { withRouter } from 'react-router-dom';
import { connect } from 'react-redux';

import * as Consts from './constants';
import CommentSection from './CommentSection';


class ListContainer extends Component {

  static propTypes = {
    id: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.number,
    ]),
    
    //opt: import {PostsShape} from './propTypes'; PropTypes.arrayOf(PostsShape),
    comments: PropTypes.array,
    total: PropTypes.number,
  }

  static perPage = 20;

  constructor(props) {
    super(props);

    this.state = {
      page: 1,
    };
  }

  componentDidMount() {
    this.props.load(this.props.id, this.state.page, this.perPage);
  }

  componentDidUpdate(prevProps, prevState) {
    if (this.props.id !== prevProps.id || this.state.page !== prevState.page) {
      this.props.load(this.props.id, this.state.page, this.perPage);
    }
  }

  createHandler = (values) => {
    this.props.createNew(values, this.props.id, 0);
  }

  render() {
    const { comments, total, load } = this.props;
    const { page } = this.state;
    const { perPage } = ListContainer;

    return (
      <CommentSection comments={comments} total={total} createNew={this.createHandler} pagerProps={{page, perPage, load, changePage: page => this.setState({page})}} />
    );
  }
}


const mapState = (state, ownProps) => {
  const id = ownProps.id || ownProps.match.params.id;
  const post = state.comments.post[id];

  return {
    id,
    comments: post ? post.items : [],
    total: post && post.total,
  };
};

const mapDispatch = (dispatch, ownProps) => ({
  load: (id) => id && dispatch({type: Consts.FORPOST_REQUEST, id}),
  createNew: (values, post, parent) =>
    dispatch({type: Consts.CREATE_REQUEST, values, post, parent})
});

export default withRouter(connect(mapState, mapDispatch)(ListContainer));
