import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { withRouter } from 'react-router-dom';
import { connect } from 'react-redux';

import { urlify } from '../utils';
import { LinkList, Pager } from '../_global';

import * as Consts from './constants';
import Page from './Page';


class ListContainer extends Component {

  static propTypes = {
    amount: PropTypes.number,
    full: PropTypes.bool,
    titles: PropTypes.bool,
    page: PropTypes.number,
    
    //opt: import {PageShape} from './propTypes'; PropTypes.arrayOf(PageShape),
    pages: PropTypes.array,
    total: PropTypes.number,

    load: PropTypes.func,
    changePage: PropTypes.func,
  }

  componentDidMount() {
    const {load, page, amount} = this.props;
    load(page, amount);
  }

  componentDidUpdate(prevProps) {
    const {load, page, amount} = this.props;
    if (page !== prevProps.page || amount > prevProps.amount) {
      load(page, amount);
    }
  }

  _makeLink(page) {
    return `/pages/detail/${page.id}/${page.title && urlify(page.title.rendered)}`;
  }

  render() {
    const { pages, page, amount, total, full, titles, changePage } = this.props;

    if (titles) {
      return (
        <LinkList links={pages.map(p => ({
          key: p.id,
          url: this._makeLink(p),
          text: p.title.rendered,
        }))} />
      );
    }

    return (
      <Pager page={page} perPage={amount} total={total} items={pages.map(p =>
        p ? <Page key={p.id} page={p} link={this._makeLink(p)} full={full} /> : null
      )} changePage={changePage} />
    );
  }
}


const mapState = (state, ownProps) => {
  return {
    full: ownProps.full,
    titles: ownProps.titles,
    page: Number.parseInt(ownProps.match.params.page) || 1,
    amount: ownProps.amount || 2,

    pages: state.pages.all.map(id => state.pages.byId[id]),
    total: state.pages.total,
  };
};

const mapDispatch = (dispatch, ownProps) => ({
  load: (page, amount) => dispatch({type: Consts.LIST_REQUEST, page, amount}),
  changePage: (page) => ownProps.history.push(`/pages/${page}`),
});

export default withRouter(connect(mapState, mapDispatch)(ListContainer));
