import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { Link } from 'react-router-dom';
import styled from 'styled-components';

import NotFound from '../NotFound';
import { TextPlaceholder, GradientBorder } from '../styles';
import { DateTime, Icon } from '../_global';

import { urlify } from '../utils';
import { UserDetail } from '../users';


const Article = styled.article`
  padding: 2rem;
  margin: 1rem 0;
`;

const Header = styled.header`
  padding: 1rem 0 0.5rem 0;
  margin-bottom: 2rem;
  ${GradientBorder()}
  border-width: 2px 0;
`;

const Title = styled.h2`
  font-size: 2rem;
  margin: 0;
  
  a {
    color: inherit;

    :hover, :active, :focus {
      text-decoration: none;
      color: #666;
    }
  }
`;

const HeaderPart = styled.span`
  display: inline-block;
  padding: 0.5rem 1.5rem 0.5rem 0;
  color: #666;
  font-weight: 600;
`;

const Body = styled.main`
  hr {
    ${GradientBorder()}
    border-bottom-width: 2px;
  }

  h2, h3, h4 {
    margin-bottom: 0;
  }

  p {
    margin-top: 0;
  }
`;

const Footer = styled.footer`
  ${GradientBorder()}
  border-top-width: 2px;
  padding: 0.5rem 0;
`;


export default class Page extends PureComponent {
  
  static propTypes = {
    full: PropTypes.bool,

    page: PropTypes.object,
    //OPT: import {PageShape} from './propTypes'; page: PageShape,
  };

  renderPlaceholder() {
    return (
      <Article>
        <Header>
          <Title>
            <TextPlaceholder />
          </Title>

          <HeaderPart>
            <TextPlaceholder />
          </HeaderPart>
        </Header>

        <Body>
          <p>
            <TextPlaceholder />
            <TextPlaceholder />
            <TextPlaceholder />
          </p>
          <p>
            <TextPlaceholder />
            <TextPlaceholder />
            <TextPlaceholder />
            <TextPlaceholder />
          </p>
          <p>
            <TextPlaceholder />
            <TextPlaceholder />
          </p>
        </Body>

        <Footer>
          <TextPlaceholder />
        </Footer>
      </Article>
    );
  }

  renderExcerpt({id, date, modified, title, excerpt, author}) {
    const link = `/pages/detail/${id}/${urlify(title.rendered)}`;

    return (
      <Article>
        <Header>
          <Title>
            <Link to={link}>
              {title.rendered}
            </Link>
          </Title>

          <HeaderPart>
            by&nbsp;
            <UserDetail embed id={author} />
          </HeaderPart>
          <HeaderPart>
            <Icon name="date" />
            <DateTime date={date} />
          </HeaderPart>
        </Header>

        <Body dangerouslySetInnerHTML={{__html: excerpt.rendered}} />

        <Footer>
          <Link to={link}>Read more</Link>
        </Footer>
      </Article>
    );
  }

  renderFull({id, date, modified, title, excerpt, content, author}) {
    return (
      <Article>
        <Header>
          <Title>{title.rendered}</Title>

          <HeaderPart>
            by&nbsp;
            <UserDetail embed id={author} />
          </HeaderPart>
          <HeaderPart>
            <Icon name="date" />
            <DateTime date={date} modified={modified} />
          </HeaderPart>
        </Header>

        <Body dangerouslySetInnerHTML={{__html: content ? content.rendered : excerpt.rendered}} />

        <Footer />
      </Article>
    );
  }

  render() {
    const {page, full} = this.props;

    if (!page) {
      return this.renderPlaceholder();
    } else if (page === 404) {
      return <NotFound />;
    } else if (!full) {
      return this.renderExcerpt(page);
    } else {
      return this.renderFull(page);
    }
  }
}
