import { } from 'redux-saga';
import { call, put, select, takeEvery } from 'redux-saga/effects';

import { getList, getDetail } from './api';
import * as Consts from './constants';


function* loadList({page, amount}) {
  try {
    const start = (page - 1) * amount;
    const all = yield select(state => state.pages.all);
    const cached = all.slice(start, start + amount).filter(a => !!a);
    //opt: pass cached.map(a=>a.id) into api as ?exclude=, to save few hundred bytes

    if (cached.length < amount) {
      const response = yield call(getList, undefined, undefined, page, amount);
      yield put({type: Consts.LIST_SUCCESS, ...response, start, amount});
    }
  } catch (error) {
    console.error(error);
    yield put({type: Consts.LIST_FAIL, error});
  }
}

function* loadDetail({id}) {
  try {
    const cached = yield select(state => state.pages.byId[id]);

    // either post not fetched, or only embed/excerpt - detail needs all content
    if (!cached || !cached.content) {
      const content = yield call(getDetail, id);
      yield put({type: Consts.DETAIL_SUCCESS, id, content});
    }
  } catch (error) {
    console.error(error);
    yield put({type: Consts.DETAIL_FAIL, id, error});
  }
}

export default function* pagesFlow() {
  yield takeEvery(Consts.LIST_REQUEST, loadList);
  yield takeEvery(Consts.DETAIL_REQUEST, loadDetail);
}
