import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { withRouter } from 'react-router-dom';
import { connect } from 'react-redux';

import { urlify } from '../utils';
import { LinkList, Pager } from '../_global';

import * as Consts from './constants';
import Post from './Post';


class ListContainer extends Component {

  static propTypes = {
    amount: PropTypes.number,
    full: PropTypes.bool,
    titles: PropTypes.bool,
    page: PropTypes.number,
    noPaging: PropTypes.bool,

    category: PropTypes.number,
    tag: PropTypes.number,
    author: PropTypes.number,
    
    //opt: import {PostsShape} from './propTypes'; PropTypes.arrayOf(PostsShape),
    posts: PropTypes.array,
    total: PropTypes.number,

    load: PropTypes.func,
    changePage: PropTypes.func,
  }

  componentDidMount() {
    const {load, page, amount, category, tag, author} = this.props;
    load(page, amount, category, tag, author);
  }

  componentDidUpdate(prevProps) {
    const {load, page, amount, category, tag, author} = this.props;
    if (page !== prevProps.page || amount > prevProps.amount || category !== prevProps.category || tag !== prevProps.tag || author !== prevProps.author) {
      load(page, amount, category, tag, author);
    }
  }

  _makeLink(page) {
    return {
      pathname: `/posts/detail/${page.id}/${page.title && urlify(page.title.rendered)}`,
      state: this.props.backLink,
    };
  }

  render() {
    const { posts, page, amount, total, full, titles, noPaging, changePage } = this.props;
  
    if (titles) {
      return (
        <LinkList links={posts.slice(0, amount).map(p => ({
          key: p.id,
          url: this._makeLink(p),
          text: p.title.rendered,
        }))} />
      );
    }

    if (noPaging) {
      return posts.slice(0, amount).map(p =>
        p ? <Post key={p.id} post={p} link={this._makeLink(p)} full={full} /> : null
      );
    }

    return (
      <Pager page={page} perPage={amount} total={total} items={posts.map(p =>
        p ? <Post key={p.id} post={p} link={this._makeLink(p)} full={full} /> : null
      )} changePage={changePage} noControls={noPaging} />
    );
  }
}


const mapState = (state, ownProps) => {
  const mp = ownProps.match.params;

  //opt: mp unnecessary now? since no Route links to PostsList except for all?
  const category = ownProps.category || (mp[0] === 'categories' && mp.id) || undefined;
  const tag = ownProps.tag || (mp[0] === 'tags' && mp.id) || undefined;
  const author = ownProps.author || (mp[0] === 'author' && mp.id) || undefined;

  let obj;
  if (category) {
    obj = category && state.posts.categories[category];
  } else if (tag) {
    obj = tag && state.posts.tags[tag];
  } else if (author) {
    obj = author && state.posts.author[author];
  } else {
    obj = state.posts.all;
  }

  return {
    category,
    tag,
    author,

    children: ownProps.children,
    amount: ownProps.amount || 2,
    full: ownProps.full,
    titles: ownProps.titles,
    backLink: ownProps.location.pathname,

    page: Number.parseInt(ownProps.match.params.page) || 1,
    posts: obj ? obj.items.map(id => state.posts.byId[id]) : [],
    total: obj ? obj.total : 0,
  };
};

const mapDispatch = (dispatch, ownProps) => ({
  load: (page, amount, category, tag, author) =>
    dispatch({type: Consts.LIST_REQUEST, page, amount, category, tag, author}),
  //opt: consider changing /posts/1 to ?page=1, possibly better handling
  changePage: (page) =>
    ownProps.history.push(ownProps.match.url.replace(/posts\/?.*$/, `posts/${page}`)),
});

export default withRouter(connect(mapState, mapDispatch)(ListContainer));
