import { mapify } from '../utils';

import * as Consts from './constants';


const initialState = {
  byId: {
    // 1: { id: 1, ..., author: 2, categories: [ 3, ], tags: [ 4, ] }
  },
  all: undefined, // "view all" rather than every single one, in order for paging
    //  items: {},
    //  total: 0,
  categories: {
    // 3: { total: 2, items: [ 1, 2, ] }
  },
  tags: {
    // 4: { total: 1, items: [ 2, ] }
  },
  author: {
    // 5: { total: 3, items: [ 1, 2, 3, ] }
  },
};

export default (state = initialState, action) => {
  switch (action.type) {
    // case Consts.ALL_SUCCESS: {
    //   // splice doesn't work the way we want with a smaller array than start; also we create a copy, since splice modifies the array
    //   const all = state.all.length === 0
    //     ? Array(action.total)
    //     : [...state.all];
    //   all.splice(action.start, action.amount, ...action.content.map(a => a.id));
    //   return {...state,
    //     byId: {...state.byId,
    //       ...mapify(action.content)
    //     },
    //     all,
    //     total: action.total,
    //   };
    // }

    // case Consts.CATEGORY_SUCCESS: {
    //   const items = state.categories[action.id]
    //     ? [...state.categories[action.id].items]
    //     : Array(action.total);
    //   items.splice(action.start, action.amount, ...action.content.map(a => a.id));
    //   return {...state,
    //     byId: {...state.byId,
    //       ...mapify(action.content)
    //     },
    //     categories: {...state.categories,
    //       [action.id]: {
    //         total: action.total,
    //         items,
    //       }
    //     },
    //   };
    // }

    case Consts.LIST_SUCCESS: {
      const total = action.total;
      let obj;
      if (action.category) {
        obj = state.categories[action.category];
      } else if (action.tag) {
        obj = state.tags[action.tag];
      } else if (action.author) {
        obj = state.author[action.author];
      } else {
        obj = state.all;
      }

      // splice doesn't work the way we want with a smaller array than start; also we create a copy, since splice modifies the array
      const items = obj ? [...obj.items] : Array(total);
      items.splice(action.start, action.amount, ...action.content.map(a => a.id));

      const newState = {...state,
        byId: {...state.byId,
          ...mapify(action.content)
        },
      };

      const newObj = { total, items }
      if (action.category) {
        newState.categories[action.category] = newObj;
      } else if (action.tag) {
        newState.tags[action.tag] = newObj;
      } else if (action.author) {
        newState.author[action.author] = newObj;
      } else {
        newState.all = newObj;
      }

      return newState;
    }

    case Consts.DETAIL_SUCCESS:
      return {...state,
        byId: {...state.byId,
          [action.id]: action.content,
        },
      };

    case Consts.DETAIL_FAIL:
      return {...state,
        byId: {...state.byId,
          [action.id]: 404,
        },
      };

    default:
      return state;
  }
}
