import { } from 'redux-saga';
import { call, put, select, takeEvery } from 'redux-saga/effects';

import { getList, getDetail } from './api';
import * as Consts from './constants';


function* loadList({category, tag, author, page, amount}) {
  try {
    const start = (page - 1) * amount;
    let posts;

    if (category) {
      posts = yield select(state => state.posts.categories[category]);
    } else if (tag) {
      posts = yield select(state => state.posts.tags[tag]);
    } else if (author) {
      posts = yield select(state => state.posts.author[author]);
    } else {
      posts = yield select(state => state.posts.all);
    }
    
    const cached = posts && posts.items.slice(start, start + amount).filter(a => !!a);
    //opt: pass cached.map(a=>a.id) into api as ?exclude=, to save few hundred bytes

    if (!cached || cached.length < amount) {
      const response = yield call(getList, category, tag, author, page, amount);
      yield put({type: Consts.LIST_SUCCESS, ...response, category, tag, author, start, amount});
    }
  } catch (error) {
    console.error(error);
    yield put({type: Consts.LIST_FAIL, error});
  }
}

function* loadDetail({id}) {
  try {
    const cached = yield select(state => state.posts.byId[id]);

    // either post not fetched, or only embed/excerpt - detail needs all content
    if (!cached || !cached.content) {
      const content = yield call(getDetail, id);
      yield put({type: Consts.DETAIL_SUCCESS, id, content});
    }
  } catch (error) {
    console.error(error);
    yield put({type: Consts.DETAIL_FAIL, id, error});
  }
}

export default function* postsFlow() {
  yield takeEvery(Consts.LIST_REQUEST, loadList);
  yield takeEvery(Consts.DETAIL_REQUEST, loadDetail);
}
