import styled, { createGlobalStyle, css } from 'styled-components';


/* Global *
 *--------*/

export default createGlobalStyle`
  html, button, input, textarea {
    font: 24px/1.6 serif;
  }

  html, body {
    margin: 0;
    padding: 0;
  }

  a {
    color: #39f;
    text-decoration: none;
    transition: color 0.333s ease;

    :hover, :focus, :active {
      color: #26c;
      text-decoration: underline;
    }
  }
`;


/* Snippets *
 *----------*/

export const GradientBorder = (width = 20) => css`
  border: 0 solid currentColor;
  border-image: linear-gradient(to right, transparent, currentColor 1em, transparent ${width}rem);
  border-image-slice: 1 0;
`;


/* Components *
 *------------*/

export const TextPlaceholder = styled.span`
  display: inline-block;
  height: 1em;
  margin-bottom: 0.4em;
  min-width: 12em;
  width: 30%;
  background: linear-gradient(to right, currentColor 50%, transparent 125%);
  opacity: 0.333;
  border-radius: 0.2em;

  &:not(:last-of-type) {
    width: 90%;
  }
`;

export const Button = styled.button`
  background: #eee;
  border: none;
  border-radius: 0.2rem;
  padding: 0.25em 0.5em 0.125em;
  margin: 0.25em;
  transition: background 0.333s ease;
  cursor: pointer;

  :enabled {
    :hover, :focus, :active {
      background: #def;
    }
  }

  :disabled {
    color: #888;
    cursor: not-allowed;
  }

  ${props => props.inline && `
    margin: 0 0.5em;
    padding: 0.125em 0.5em 0;
  `}
`;

export const InlineImage = styled.img`
  width: 1.2em;
  height: 1.2em;
  object-fit: contain;
  vertical-align: middle;
  padding-right: 0.125em;
  padding-bottom: 0.25em;
`;
