import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { Link } from 'react-router-dom';
import styled from 'styled-components';

import { TextPlaceholder, GradientBorder, InlineImage } from '../styles';

import { PostsList } from '../posts';


//opt: comment list?

const Article = styled.article`
  padding: 2rem;
  margin: 1rem 0;
`;

const Header = styled.header`
  padding: 1rem 0 0.5rem 0;
  margin-bottom: 2rem;
  ${GradientBorder()}
  border-width: 2px 0;
`;

const Title = styled.h2`
  font-size: 2rem;
  margin: 0;
  
  a {
    color: inherit;

    :hover, :active, :focus {
      text-decoration: none;
      color: #666;
    }
  }
`;

const HeaderPart = styled.span`
  display: inline-block;
  padding: 0.5rem 1.5rem 0.5rem 0;
  color: #666;
  font-weight: 600;
`;

const Body = styled.main`
  hr {
    ${GradientBorder()}
    border-bottom-width: 2px;
  }

  h2, h3, h4 {
    margin-bottom: 0;
  }

  p {
    margin-top: 0;
  }
`;

const Footer = styled.footer`
  ${GradientBorder()}
  border-top-width: 2px;
  padding: 0.5rem 0;
`;


export default class Post extends Component {
  
  static propTypes = {
    //OPT: import {UserShape} from './propTypes'; post: UserShape,
    user: PropTypes.object,
  };

  renderPlaceholder() {
    return (
      <Article>
        <Header>
          <Title>
            <TextPlaceholder />
          </Title>

          <HeaderPart>
            <TextPlaceholder />
          </HeaderPart>
          <HeaderPart>
            <TextPlaceholder />
          </HeaderPart>
        </Header>

        <Body>
          <p>
            <TextPlaceholder />
            <TextPlaceholder />
            <TextPlaceholder />
          </p>
          <p>
            <TextPlaceholder />
            <TextPlaceholder />
          </p>
        </Body>

        <Footer>
          <TextPlaceholder />
        </Footer>
      </Article>
    );
  }

  renderFull({id, name, url, description, avatar_urls}) {
    return (
      <Article>
        <Header>
          <Title>
            <InlineImage src={avatar_urls[48]} />
            {name}
          </Title>

          {url && <HeaderPart>
            <Link to={url}>{url}</Link>
          </HeaderPart>}
        </Header>

        <Body dangerouslySetInnerHTML={{__html: description }} />

        <PostsList author={id} />
      </Article>
    );
  }

  render() {
    const {user} = this.props;

    if (!user) {
      return this.renderPlaceholder();
    } else {
      return this.renderFull(user);
    }
  }
}
