import request from 'superagent';


export function log(message, level = 'log') {
  if (process.env.NODE_ENV !== 'production') {
    if (Array.isArray(message)) {
      console[level](...message);
    } else {
      console[level](message);
    }
  }
}

export function mapify(array, id = 'id') {
  return array.reduce((accumulator, item) => {
    accumulator[item[id]] = item;
    return accumulator;
  }, {});
}

export function urlify(string) {
  return string.replace(/\s/g, '_').replace(/[^A-z_]/g, '')
}

export function httpGet(path, query, responseHeaders = false) {
  return (request
    .get(process.env.REACT_APP_BACKEND + path)
    .query(query)
    //opt: callback executed for first try, not only on re-try
    .retry(3)//, (err, res) => log(['GET Request to ', path, '?', query, ' failed, retrying...'], 'warn'))
    .then((response) => {
      log(['GET Request to ', path, '?', query, ' successful, returned: ', response]);
      return responseHeaders ? response : response.body;
    })
    .catch(({message, response}) => {
      log(['GET Request to ', path, '?', query, ' failed, message: ', message], 'error');
      throw message;
    })
  );
}

export function httpPost(path, query, body) {
  return (request
    .post(process.env.REACT_APP_BACKEND + path)
    .query(query)
    .send(body)
    //opt: callback executed for first try, not only on re-try
    .retry(3)//, (err, res) => log(['POST Request to ', path, '?', query, ' failed, retrying...'], 'warn'))
    .then((response) => {
      log(['POST Request to ', path, '?', query, ' with body ', body, ' successful, returned: ', response]);
      return response;
    })
    .catch(({message, response}) => {
      log(['POST Request to ', path, '?', query, ' with body ', body, ' failed, message: ', message], 'error');
      throw message;
    })
  );
}
